# shelter: couch: parts

continues [v1](./v1.md).

|   |   |   |   |   |   |
| --- | --- | --- | --- | --- | --- |
| [`220VAC dimmer`](../parts/220VAC-dimmer.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/220VAC-dimmer.jpeg?raw=true)](../parts/220VAC-dimmer.md)  | [`AC volt meter`](../parts/ac-volt-meter.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/ac-volt-meter.jpg?raw=true)](../parts/ac-volt-meter.md) 220 V, 1 A | [`mountable digital thermometer`](../parts/mountable-digital-thermometer.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/mountable-digital-thermometer.jpeg?raw=true)](../parts/mountable-digital-thermometer.md)  | [`nuts, bolts, and spacers`](../parts/nuts-bolts-spacers.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/nuts-bolts-spacers.jpg?raw=true)](../parts/nuts-bolts-spacers.md) M3: (4 x bolt + 4 x nut + 4 x 35 mm spacer) | [`plexiglass, 2 mm or 2.5 mm thickness`](../parts/plexiglass.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/plexiglass.jpg?raw=true)](../parts/plexiglass.md) 2 x 9 cm x 7 cm | [`resistance heating wire`](../parts/resistance-heating-wire.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/resistance-heating-wire.jpg?raw=true)](../parts/resistance-heating-wire.md) 1.59 kΩ |

1. [220VAC dimmer](../parts/220VAC-dimmer.md).
1. [AC volt meter](../parts/ac-volt-meter.md): 220 V, 1 A.
1. [mountable digital thermometer](../parts/mountable-digital-thermometer.md).
1. [nuts, bolts, and spacers](../parts/nuts-bolts-spacers.md): M3: (4 x bolt + 4 x nut + 4 x 35 mm spacer).
1. [plexiglass, 2 mm or 2.5 mm thickness](../parts/plexiglass.md): 2 x 9 cm x 7 cm.
1. [resistance heating wire](../parts/resistance-heating-wire.md): 1.59 kΩ.
